@@ -17,6 +17,9 @@ from tvb.datatypes.time_series import TimeSeries
 from tvbwidgets.core.ini_parser import parse_ini_file
 from tvbwidgets.core.exceptions import InvalidInputException
 from tvbwidgets.ui.base_widget import TVBWidget
+from tvbwidgets.ui.widget_with_browser import TVBWidgetWithBrowser
+
+mne.set_config('MNE_BROWSER_BACKEND', 'matplotlib')
 
 
 class ABCDataWrapper(ABC):
@@ -263,8 +266,8 @@ class TimeSeriesWidget(widgets.VBox, TVBWidget):
 
         self.output = widgets.Output(layout=widgets.Layout(width='auto'))
         annotation_area = self._create_annotation_area()
-        instr_area = self._create_instructions_region()
-        self.title_area = widgets.HBox(children=[instr_area])
+        self.instr_area = self._create_instructions_region()
+        self.title_area = widgets.HBox(children=[self.instr_area])
 
         self.checkboxes = dict()
         super().__init__([self.output, annotation_area, self.title_area], layout=self.DEFAULT_BORDER)
@@ -276,10 +279,15 @@ class TimeSeriesWidget(widgets.VBox, TVBWidget):
         self.logger.debug("Adding TVB TS for display...")
         self._populate_from_data_wrapper(data_wrapper)
 
+    def reset_data(self):
+        self.data = None
+        self.title_area.children = [self.instr_area]
+
     def _populate_from_data_wrapper(self, data_wrapper):
         # type: (ABCDataWrapper) -> None
         if self.data is not None:
-            raise InvalidInputException("TSWidget is not yet capable to display more than one TS!")
+            raise InvalidInputException("TSWidget is not yet capable to display more than one TS, "
+                                        "either use wid.reset_data, or create another widget instance!")
 
         self.data = data_wrapper
         self.sample_freq = data_wrapper.get_ts_sample_rate()
@@ -336,6 +344,7 @@ class TimeSeriesWidget(widgets.VBox, TVBWidget):
                 cb = self.checkboxes[ch_name]
                 if not cb.value:
                     cb.value = True
+            self._update_fig()
 
         def hover(event):
             self.channel_val_area.children = []
@@ -373,7 +382,6 @@ class TimeSeriesWidget(widgets.VBox, TVBWidget):
             self.fig.canvas.mpl_connect('key_press_event', update_on_plot_interaction)
             self.fig.canvas.mpl_connect('button_press_event', update_on_plot_interaction)
             self.fig.canvas.mpl_connect("motion_notify_event", hover)
-
             with self.output:
                 self.output.clear_output(wait=True)
                 display(self.fig.canvas)
@@ -535,3 +543,22 @@ class TimeSeriesWidget(widgets.VBox, TVBWidget):
             self.fig._redraw(annotations=True)
         except:
             self.fig._redraw(update_data=False)  # needed in case of Unselect all
+
+
+class TimeSeriesBrowser(widgets.VBox, TVBWidgetWithBrowser):
+
+    def __init__(self, collab=None, folder=None):
+        super().__init__(**{'collab': collab, 'folder': folder})
+        timeseries_button = widgets.Button(description='View time series')
+        self.buttons = widgets.HBox([timeseries_button], layout=widgets.Layout(margin="0px 0px 0px 20px"))
+        self.timeseries_widget = TimeSeriesWidget()
+        self.children = [self.storage_widget, self.buttons, self.message_label, self.timeseries_widget]
+
+        def add_timeseries_datatype(_):
+            self.load_selected_file(TimeSeries, ('.h5', '.npz'))
+
+        timeseries_button.on_click(add_timeseries_datatype)
+
+    def add_datatype(self, datatype):  # type: (TimeSeries) -> None
+        self.timeseries_widget.reset_data()
+        self.timeseries_widget.add_datatype(datatype)
